@@ -1,5 +1,5 @@
 /*
- * $Id: sendserver.c,v 1.13 1996/05/05 00:13:07 lf Exp $
+ * $Id: sendserver.c,v 1.14 1996/05/13 00:05:20 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -34,7 +34,6 @@
 #include	"radius.h"
 #include	"pathnames.h"
 
-void md5_calc (unsigned char *, unsigned char *, unsigned int);
 static void rc_random_vector (unsigned char *);
 static int rc_check_reply (AUTH_HDR *, char *, unsigned char *, unsigned char);
 
@@ -69,7 +68,7 @@ static int rc_pack_list (VALUE_PAIR *vp, char *secret, AUTH_HDR *auth)
 		  *buf++ = AUTH_PASS_LEN + 2;
 
 		  /* Encrypt the Password */
-		  length = strlen (vp->strvalue);
+		  length = vp->lvalue;
 		  if (length > AUTH_PASS_LEN)
 		  {
 			length = AUTH_PASS_LEN;
@@ -92,13 +91,14 @@ static int rc_pack_list (VALUE_PAIR *vp, char *secret, AUTH_HDR *auth)
 		  
 		  total_length += AUTH_PASS_LEN + 2;
 		  
-		  break;		
+		  break;
+#if 0		
 		 case PW_CHAP_PASSWORD:
 
 		  *buf++ = CHAP_VALUE_LENGTH + 2;
 
 		  /* Encrypt the Password */
-		  length = strlen (vp->strvalue);
+		  length = vp->lvalue;
 		  if (length > CHAP_VALUE_LENGTH)
 		  {
 			length = CHAP_VALUE_LENGTH;
@@ -121,11 +121,12 @@ static int rc_pack_list (VALUE_PAIR *vp, char *secret, AUTH_HDR *auth)
 		  total_length += CHAP_VALUE_LENGTH + 2;
 		 
 		  break;
+#endif
 		 default:
 		  switch (vp->type)
 		  {
 		    case PW_TYPE_STRING:
-			length = strlen (vp->strvalue);
+			length = vp->lvalue;
 			*buf++ = length + 2;
 			memcpy (buf, vp->strvalue, (size_t) length);
 			buf += length;
