@@ -1,5 +1,5 @@
 /*
- * $Id: radexample.c,v 1.4 1996/05/05 00:13:36 lf Exp $
+ * $Id: radexample.c,v 1.5 1996/05/13 00:05:36 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -11,7 +11,7 @@
 
 
 static char	rcsid[] =
-		"$Id: radexample.c,v 1.4 1996/05/05 00:13:36 lf Exp $";
+		"$Id: radexample.c,v 1.5 1996/05/13 00:05:36 lf Exp $";
 
 #include	<sys/types.h>
 
@@ -64,14 +64,14 @@ main (int argc, char **argv)
 		strncat(username_realm, default_realm, sizeof(username_realm));
 	} 
 
-	if (rc_avpair_add(&send, PW_USER_NAME, username_realm) == NULL)
+	if (rc_avpair_add(&send, PW_USER_NAME, username_realm, 0) == NULL)
 		return(ERROR_RC);
 	
 	/*
 	 * Fill in User-Password
 	 */
 	 
-	if (rc_avpair_add(&send, PW_USER_PASSWORD, passwd) == NULL)
+	if (rc_avpair_add(&send, PW_USER_PASSWORD, passwd, 0) == NULL)
 		return (ERROR_RC);
 
 	/*
@@ -79,7 +79,7 @@ main (int argc, char **argv)
 	 */
 	
 	service = PW_AUTHENTICATE_ONLY;
-	if (rc_avpair_add(&send, PW_SERVICE_TYPE, &service) == NULL)
+	if (rc_avpair_add(&send, PW_SERVICE_TYPE, &service, 0) == NULL)
 		return (ERROR_RC);	
 	
 	result = rc_auth(0, send, &received, msg);
